<h1 align="center">Renfepy</h1>
<p align="center">Python library to search for trains on renfe.es<p>


# Installation
`pip3 install renfepy`

# Usage
## Normal execution
`renfepy <origin> <destination> <going_date>`

## Parameters
-g, --gui: Show browser
-r, --return: Set return date
-t, --type: Set type of train